@@ -19,7 +19,7 @@
 
 #define QT_FEATURE_gstreamer_gl 1
 
-#define QT_FEATURE_gstreamer_gl_wayland 1
+#define QT_FEATURE_gstreamer_gl_wayland -1
 
 #define QT_FEATURE_gstreamer_gl_egl 1
 
